@@ -22,7 +22,7 @@ impl Serialized {
             len.try_into()
                 .expect("Cannot determine size of the serialized bytes"),
         );
-        vec.extend_from_slice(&bytes);
+        vec.extend_from_slice(bytes);
         Serialized { field: vec }
     }
 
@@ -30,6 +30,7 @@ impl Serialized {
         Serialized { field: vec }
     }
 
+    #[allow(clippy::should_implement_trait)]
     pub fn as_ref(&self) -> &rkyv::AlignedVec {
         &self.field
     }
@@ -39,7 +40,7 @@ impl Serialized {
         W: rkyv::Serialize<rkyv::ser::serializers::AllocSerializer<512>>,
     {
         rkyv::to_bytes::<_, 512>(t)
-            .map(|v| Serialized::from(v))
+            .map(Serialized::from)
             .map_err(|err| match err {
                 rkyv::ser::serializers::CompositeSerializerError::SerializerError(e) => e.into(),
                 rkyv::ser::serializers::CompositeSerializerError::ScratchSpaceError(e) => {
