@@ -183,7 +183,7 @@ impl FileName {
 ///   and would be rendered with `^^^`.
 /// - they can have a *label*. In this case, the label is written next to the
 ///   mark in the snippet when we render.
-#[derive(Clone, Debug, Hash, PartialEq, Eq)]
+#[derive(Clone, Debug, Default, Hash, PartialEq, Eq)]
 #[cfg_attr(
     feature = "diagnostic-serde",
     derive(serde::Serialize, serde::Deserialize)
@@ -441,10 +441,7 @@ impl Default for Span {
 impl MultiSpan {
     #[inline]
     pub fn new() -> MultiSpan {
-        MultiSpan {
-            primary_spans: vec![],
-            span_labels: vec![],
-        }
+        Self::default()
     }
 
     pub fn from_span(primary_span: Span) -> MultiSpan {
@@ -726,11 +723,7 @@ impl SourceFile {
         }
 
         let begin = {
-            let line = if let Some(line) = self.lines.get(line_number) {
-                line
-            } else {
-                return None;
-            };
+            let line = self.lines.get(line_number)?;
             let begin: BytePos = *line - self.start_pos;
             begin.to_usize()
         };
@@ -788,7 +781,7 @@ impl SourceFile {
 
 /// Remove utf-8 BOM if any.
 fn remove_bom(src: &mut String) {
-    if src.starts_with("\u{feff}") {
+    if src.starts_with('\u{feff}') {
         src.drain(..3);
     }
 }
